==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/SummaryChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryChangedEventArgsDescription } from "./SummaryChangedEventArgsDescription";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryChangedEventArgsDescriptionMetadata, _super);
    function SummaryChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SummaryChangedEventArgsDescriptionMetadata.a == null) {
            SummaryChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryChangedEventArgsDescriptionMetadata.c(SummaryChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(SummaryChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("ID", "String");
        a.item("IsEnabled", "Boolean");
    };
    SummaryChangedEventArgsDescriptionMetadata.d = function (a) {
        SummaryChangedEventArgsDescriptionMetadata.b(a);
        a.aa("SummaryChangedEventArgs", function () { return new SummaryChangedEventArgsDescription(); });
        a.z("SummaryChangedEventArgs", SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.$t = markType(SummaryChangedEventArgsDescriptionMetadata, 'SummaryChangedEventArgsDescriptionMetadata');
    SummaryChangedEventArgsDescriptionMetadata.a = null;
    return SummaryChangedEventArgsDescriptionMetadata;
}(Base));
export { SummaryChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/SummaryChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SummaryChangedEventArgsDescription } from "./SummaryChangedEventArgsDescription";
/**
 * @hidden
 */
var SummaryChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(SummaryChangedEventArgsDescriptionMetadata, _super);
    function SummaryChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryChangedEventArgsDescriptionMetadata.b = function (a) {
        if (SummaryChangedEventArgsDescriptionMetadata.a == null) {
            SummaryChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryChangedEventArgsDescriptionMetadata.c(SummaryChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(SummaryChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("ID", "String");
        a.item("IsEnabled", "Boolean");
    };
    SummaryChangedEventArgsDescriptionMetadata.d = function (a) {
        SummaryChangedEventArgsDescriptionMetadata.b(a);
        a.ac("SummaryChangedEventArgs", function () { return new SummaryChangedEventArgsDescription(); });
        a.ab("SummaryChangedEventArgs", SummaryChangedEventArgsDescriptionMetadata.a);
    };
    SummaryChangedEventArgsDescriptionMetadata.$t = markType(SummaryChangedEventArgsDescriptionMetadata, 'SummaryChangedEventArgsDescriptionMetadata');
    SummaryChangedEventArgsDescriptionMetadata.a = null;
    return SummaryChangedEventArgsDescriptionMetadata;
}(Base));
export { SummaryChangedEventArgsDescriptionMetadata };
